@@ -364,7 +364,13 @@ def auto_thankanator(cmdargs):
         else:
             # This is a patch series
             commits = auto_locate_series(gitdir, jsondata, wantbranch, since=cmdargs.since)
-            if commits is None:
+            # Weed out series that have no matches at all
+            found = False
+            for commit in commits:
+                if commit[0] is not None:
+                    found = True
+                    break
+            if not found:
                 continue
             jsondata['commits'] = commits
         applied.append(jsondata)
@@ -561,13 +567,10 @@ def get_wanted_branch(cmdargs):
         logger.debug('will check branch=%s', wantbranch)
     else:
         # Make sure it's a real branch
-        gitargs = ['branch', '--format=%(refname:short)', '--list', '--all']
+        gitargs = ['branch', '--format=%(refname)', '--list', '--all', cmdargs.branch]
         lines = b4.git_get_command_lines(gitdir, gitargs)
         if not len(lines):
-            logger.critical('Not able to get a list of branches (git branch --list --all)')
-            sys.exit(1)
-        if cmdargs.branch not in lines:
-            logger.critical('Requested branch %s not found in git branch --list --all', cmdargs.branch)
+            logger.critical('Requested branch not found in git branch --list --all %s', cmdargs.branch)
             sys.exit(1)
         wantbranch = cmdargs.branch
 
@@ -583,15 +586,33 @@ def get_branch_info(gitdir, branch):
 
     remotecfg = b4.get_config_from_git('branch\\.%s\\.*' % branch)
     if remotecfg is None or 'remote' not in remotecfg:
-        # Not found any matching remotes
-        return BRANCH_INFO
+        # Did not find a matching branch entry, so look at remotes
+        gitargs = ['remote', 'show']
+        lines = b4.git_get_command_lines(gitdir, gitargs)
+        if not len(lines):
+            # No remotes? Hmm...
+            return BRANCH_INFO
 
-    BRANCH_INFO['remote'] = remotecfg['remote']
-    if 'merge' in remotecfg:
-        BRANCH_INFO['branch'] = re.sub(r'^refs/heads/', '', remotecfg['merge'])
+        remote = None
+        for entry in lines:
+            if branch.find(f'{entry}/') == 0:
+                remote = entry
+                break
+
+        if remote is None:
+            # Not found any matching remotes
+            return BRANCH_INFO
+
+        BRANCH_INFO['remote'] = remote
+        BRANCH_INFO['branch'] = branch.replace(f'{remote}/', '')
+
+    else:
+        BRANCH_INFO['remote'] = remotecfg['remote']
+        if 'merge' in remotecfg:
+            BRANCH_INFO['branch'] = re.sub(r'^refs/heads/', '', remotecfg['merge'])
 
     # Grab template overrides
-    remotecfg = b4.get_config_from_git('remote\\.%s\\..*' % remotecfg['remote'])
+    remotecfg = b4.get_config_from_git('remote\\.%s\\..*' % BRANCH_INFO['remote'])
     BRANCH_INFO.update(remotecfg)
 
     return BRANCH_INFO
